summarynb package
=================

Submodules
----------

summarynb.cli module
--------------------

.. automodule:: summarynb.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: summarynb
    :members:
    :undoc-members:
    :show-inheritance:
